/*
 * keyboard.h
 *
 * Copyright 2007, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef dev_console_keyboard_h
#define dev_console_keyboard_h


#ifndef ASM_FILE


enum{
	KEYBOARD_COMMAND_REG	= 0x64,		/* Command IO register */
	KEYBOARD_STAT_REG		= 0x64,		/* Status IO register */
	KEYBOARD_OUTPUT_REG		= 0x60		/* Data IO register */
};


//extern void initKeyboard();


#endif


#endif
